==> physics-1.0.0.tar.gz: physics-1.0.0/physics/__init__.py <==
# This file is a part of physics
#
# Copyright (c) 2018 The physics Authors (see AUTHORS)
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice
# shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

# It imports "errors" class from errors.py
from .errors import Errors

# It imports "proportionality" class from proportionality.py
from .proportionality import Proportionality

# It imports "gravity" class from gravity.py
from .gravity import Gravity

# It imports "numbers" class from numbers.py
from .numbers import Numbers

"""
physics
~~~~~~~~~~~~~~~
An educational project about Physics.
"""

__author__ = 'pyTeens'
__license__ = 'GNU GENERAL PUBLIC LICENSE'
__url__ = 'https://github.com/pyTeens/physics'
__package__ = 'physics'
__version__ = '1.0.0'

==> physics-2.0.0.tar.gz: physics-2.0.0/physics/__init__.py <==
# This file is a part of physics
#
# Copyright (c) 2018 The physics Authors (see AUTHORS)
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice
# shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

# It imports "errors" class from errors.pyx
from physics.errors import Errors

# It imports "proportionality" class from proportionality.pyx
from physics.proportionality import Proportionality

# It imports "gravity" class from gravity.pyx
from physics.gravity import Gravity

# It imports "numbers" class from numbers.pyx
from physics.numbers import Numbers

"""
physics
~~~~~~~~~~~~~~~
An educational project about Physics.
"""

__author__ = 'pyTeens'
__license__ = 'GNU GENERAL PUBLIC LICENSE'
__url__ = 'https://github.com/pyTeens/physics'
__package__ = 'physics'
__version__ = '2.0.0'
